@@ -69,7 +69,7 @@ sub getID {
 	if (not defined $trustedID) {
 		if (defined $params->{'auth'}) {
 			# use a user-overridable auth function
-			($trustedID,$authQuality) = FAQ::OMatic::AuthLocal::authenticate($params);
+			($trustedID,$authQuality) = authenticate($params);
 		} elsif (defined $params->{'id'}) {
 			# id without authorization
 			$trustedID = $params->{'id'};
@@ -151,7 +151,12 @@ sub getInheritedProperty {
 
 # ensurePerm()
 # Checks permissions, returns '' if okay, else returns a redirect to
-# authenticate. A good use is:
+# authenticate.
+# In list context, returns the same value followed by a quality
+# value, so if you require two ensurePerms, you return the redirect
+# with the higher qualityf value (so the user gets all the authentication
+# done at once). See submitMove.
+# A good use is:
 # my $rd = ensurePerm(...);
 # if ($rd) { print $rd; exit 0; }
 sub ensurePerm {
@@ -165,6 +170,7 @@ sub ensurePerm {
 							# clicking "edit" and "submit", which annoys.
 	my $xreason = shift;	# an extra reason, needed to distinguish
 							# two cases (modOptions) in editItem.
+	my $result = '';
 
 	$cookieActual += $cookieExtra if ($extraTime);
 
@@ -174,10 +180,11 @@ sub ensurePerm {
 		my $url = FAQ::OMatic::makeAref('authenticate',
 			{'_restart' => $restart, '_reason'=>$authFailed,
 			 '_xreason'=>$xreason}, 'url', 'saveTransients');
-		return $cgi->redirect(FAQ::OMatic::urlBase($cgi).$url);
+		$result = $cgi->redirect(FAQ::OMatic::urlBase($cgi).$url);
 	}
 
-	return '';
+	return wantarray	? ($result, $authFailed)
+						: $result;
 }
 
 sub newCookie {
@@ -324,7 +331,11 @@ sub readIDfile {
 
 sub checkCryptPass {
 	my ($cleartext, $crypted) = @_;
-	my $salt = substr($crypted, 0, 2);
+	#my $salt = substr($crypted, 0, 2);
+	# specific fix from Evan Torrie <torrie@pi.pair.com>: most crypt()s
+	# don't care of there's excess salt, and those with MD5 crypts use
+	# more than the first two bytes as salt.
+	my $salt = $crypted;
 	return (crypt($cleartext, $salt) eq $crypted);
 }
 
@@ -336,6 +347,49 @@ sub cryptPass {
 	return crypt($pass,$salt);
 }
 
+sub authenticate {
+	my $params = shift;
+
+	my $auth = $params->{'auth'};
+
+	# if there's a cookie...
+	if ($auth =~ m/^ck/) {
+		my ($cookie,$cid,$ctime) = findCookie($auth,'cookie');
+		# and it's good, then return the implied id
+		return ($cid,5) if (defined $cid);
+		# if it's bad, fall through and inherit anonymous auth
+	}
+
+	# if we authenticate...
+	if ($params->{'auth'} eq 'pass' or
+		(($params->{'_none_id'} eq '') and ($params->{'_pass_id'} ne ''))) {
+		my $id = $params->{'_pass_id'};
+		my $pass = $params->{'_pass_pass'};
+		if (FAQ::OMatic::AuthLocal::checkPassword($id, $pass)) {
+			# set up a cookie to use for a shortcut later,
+			# and return the authentication pair
+			$params->{'auth'} = newCookie($id);
+			return ($id,5);
+		} else {
+			# let authenticate know to report the bad password
+			$params->{'badPass'} = 1;
+			# fall through to inherit some crummier Authentication Quality
+		}
+	}
+
+	if (($params->{'auth'} eq 'none')
+		and (defined $params->{'_none_id'})) {
+		# move id where we can pass it around
+		$params->{'id'} = $params->{'_none_id'};
+	}
+
+	# default authentication: whatever id we can come up with,
+	# but quality is at most 3
+	my $id = $params->{'id'} || 'anonymous';
+	my $aq = $params->{'id'} ? 3 : 1;
+	return ($id, $aq);
+}
+
 %staticErrors = (
 	9 => 'the administrator of this Faq-O-Matic',
 	7 => 'the moderator of the item',
